==> highs_1.10.0-2.tar.gz: highs/R/constants.R <==

HIGHS_OPTIONS <- structure(list(option = c("presolve", "solver", "parallel", "run_crossover", 
"time_limit", "read_solution_file", "read_basis_file", "write_model_file", 
"solution_file", "write_basis_file", "random_seed", "ranging", 
"infinite_cost", "infinite_bound", "small_matrix_value", "large_matrix_value", 
"primal_feasibility_tolerance", "dual_feasibility_tolerance", 
"ipm_optimality_tolerance", "primal_residual_tolerance", "dual_residual_tolerance", 
"objective_bound", "objective_target", "threads", "user_bound_scale", 
"user_cost_scale", "highs_debug_level", "highs_analysis_level", 
"simplex_strategy", "simplex_scale_strategy", "simplex_crash_strategy", 
"simplex_dual_edge_weight_strategy", "simplex_primal_edge_weight_strategy", 
"simplex_iteration_limit", "simplex_update_limit", "simplex_min_concurrency", 
"simplex_max_concurrency", "log_file", "write_model_to_file", 
"write_presolved_model_to_file", "write_solution_to_file", "write_solution_style", 
"glpsol_cost_row_location", "write_presolved_model_file", "output_flag", 
"log_to_console", "timeless_log", "ipm_iteration_limit", "pdlp_native_termination", 
"pdlp_scaling", "pdlp_iteration_limit", "pdlp_e_restart_method", 
"pdlp_d_gap_tol", "qp_iteration_limit", "qp_nullspace_limit", 
"iis_strategy", "blend_multi_objectives", "log_dev_level", "log_githash", 
"solve_relaxation", "allow_unbounded_or_infeasible", "use_implied_bounds_from_presolve", 
"lp_presolve_requires_basis_postsolve", "mps_parser_type_free", 
"use_warm_start", "keep_n_rows", "cost_scale_factor", "allowed_matrix_scale_factor", 
"allowed_cost_scale_factor", "ipx_dualize_strategy", "simplex_dualize_strategy", 
"simplex_permute_strategy", "max_dual_simplex_cleanup_level", 
"max_dual_simplex_phase1_cleanup_level", "simplex_price_strategy", 
"simplex_unscaled_solution_strategy", "presolve_reduction_limit", 
"restart_presolve_reduction_limit", "presolve_substitution_maxfillin", 
"presolve_rule_off", "presolve_rule_logging", "presolve_remove_slacks", 
"simplex_initial_condition_check", "no_unnecessary_rebuild_refactor", 
"simplex_initial_condition_tolerance", "rebuild_refactor_solution_error_tolerance", 
"dual_steepest_edge_weight_error_tolerance", "dual_steepest_edge_weight_log_error_threshold", 
"dual_simplex_cost_perturbation_multiplier", "primal_simplex_bound_perturbation_multiplier", 
"dual_simplex_pivot_growth_tolerance", "presolve_pivot_threshold", 
"factor_pivot_threshold", "factor_pivot_tolerance", "start_crossover_tolerance", 
"less_infeasible_DSE_check", "less_infeasible_DSE_choose_row", 
"use_original_HFactor_logic", "run_centring", "max_centring_steps", 
"centring_ratio_tolerance", "icrash", "icrash_dualize", "icrash_strategy", 
"icrash_starting_weight", "icrash_iterations", "icrash_approx_iter", 
"icrash_exact", "icrash_breakpoints", "mip_detect_symmetry", 
"mip_allow_restart", "mip_max_nodes", "mip_max_stall_nodes", 
"mip_max_start_nodes", "mip_max_leaves", "mip_max_improving_sols", 
"mip_lp_age_limit", "mip_pool_age_limit", "mip_pool_soft_limit", 
"mip_pscost_minreliable", "mip_min_cliquetable_entries_for_parallelism", 
"mip_report_level", "mip_feasibility_tolerance", "mip_rel_gap", 
"mip_abs_gap", "mip_heuristic_effort", "mip_min_logging_interval", 
"mip_heuristic_run_rins", "mip_heuristic_run_rens", "mip_heuristic_run_root_reduced_cost", 
"mip_heuristic_run_zi_round", "mip_heuristic_run_shifting", "mip_improving_solution_save", 
"mip_improving_solution_report_sparse", "mip_improving_solution_file", 
"mip_root_presolve_only", "mip_lifting_for_probing"), type = c("string", 
"string", "string", "string", "double", "string", "string", "string", 
"string", "string", "integer", "string", "double", "double", 
"double", "double", "double", "double", "double", "double", "double", 
"double", "double", "integer", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "string", "bool", 
"bool", "bool", "integer", "integer", "string", "bool", "bool", 
"bool", "integer", "bool", "bool", "integer", "integer", "double", 
"integer", "integer", "integer", "bool", "integer", "bool", "bool", 
"bool", "bool", "bool", "bool", "bool", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "bool", "bool", "bool", "bool", "double", "double", 
"double", "double", "double", "double", "double", "double", "double", 
"double", "double", "bool", "bool", "bool", "bool", "integer", 
"double", "bool", "bool", "string", "double", "integer", "integer", 
"bool", "bool", "bool", "bool", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "integer", "double", "double", "double", "double", 
"double", "bool", "bool", "bool", "bool", "bool", "bool", "bool", 
"string", "bool", "integer")), class = "data.frame", row.names = c(NA, 
-137L))

==> highs_1.12.0-2.tar.gz: highs/R/constants.R <==

HIGHS_OPTIONS <- structure(list(option = c("presolve", "solver", "parallel", "run_crossover", 
"time_limit", "read_solution_file", "read_basis_file", "write_model_file", 
"solution_file", "write_basis_file", "random_seed", "ranging", 
"infinite_cost", "infinite_bound", "small_matrix_value", "large_matrix_value", 
"kkt_tolerance", "primal_feasibility_tolerance", "dual_feasibility_tolerance", 
"primal_residual_tolerance", "dual_residual_tolerance", "optimality_tolerance", 
"objective_bound", "objective_target", "threads", "user_objective_scale", 
"user_bound_scale", "highs_debug_level", "highs_analysis_level", 
"simplex_strategy", "simplex_scale_strategy", "simplex_crash_strategy", 
"simplex_dual_edge_weight_strategy", "simplex_primal_edge_weight_strategy", 
"simplex_iteration_limit", "simplex_update_limit", "simplex_min_concurrency", 
"simplex_max_concurrency", "log_file", "write_model_to_file", 
"write_presolved_model_to_file", "write_solution_to_file", "write_solution_style", 
"glpsol_cost_row_location", "write_presolved_model_file", "write_iis_model_file", 
"output_flag", "log_to_console", "timeless_log", "ipm_optimality_tolerance", 
"ipm_iteration_limit", "hipo_system", "hipo_parallel_type", "hipo_block_size", 
"hipo_metis_no2hop", "pdlp_scaling", "pdlp_iteration_limit", 
"pdlp_e_restart_method", "pdlp_optimality_tolerance", "qp_iteration_limit", 
"qp_nullspace_limit", "qp_regularization_value", "iis_strategy", 
"blend_multi_objectives", "log_dev_level", "log_githash", "solve_relaxation", 
"allow_unbounded_or_infeasible", "use_implied_bounds_from_presolve", 
"lp_presolve_requires_basis_postsolve", "mps_parser_type_free", 
"use_warm_start", "keep_n_rows", "cost_scale_factor", "allowed_matrix_scale_factor", 
"allowed_cost_scale_factor", "ipx_dualize_strategy", "simplex_dualize_strategy", 
"simplex_permute_strategy", "max_dual_simplex_cleanup_level", 
"max_dual_simplex_phase1_cleanup_level", "simplex_price_strategy", 
"simplex_unscaled_solution_strategy", "presolve_reduction_limit", 
"restart_presolve_reduction_limit", "presolve_substitution_maxfillin", 
"presolve_rule_off", "presolve_rule_logging", "presolve_remove_slacks", 
"simplex_initial_condition_check", "no_unnecessary_rebuild_refactor", 
"simplex_initial_condition_tolerance", "rebuild_refactor_solution_error_tolerance", 
"dual_steepest_edge_weight_error_tolerance", "dual_steepest_edge_weight_log_error_threshold", 
"dual_simplex_cost_perturbation_multiplier", "primal_simplex_bound_perturbation_multiplier", 
"dual_simplex_pivot_growth_tolerance", "presolve_pivot_threshold", 
"factor_pivot_threshold", "factor_pivot_tolerance", "start_crossover_tolerance", 
"less_infeasible_DSE_check", "less_infeasible_DSE_choose_row", 
"use_original_HFactor_logic", "run_centring", "max_centring_steps", 
"centring_ratio_tolerance", "icrash", "icrash_dualize", "icrash_strategy", 
"icrash_starting_weight", "icrash_iterations", "icrash_approx_iter", 
"icrash_exact", "icrash_breakpoints", "mip_detect_symmetry", 
"mip_allow_restart", "mip_max_nodes", "mip_max_stall_nodes", 
"mip_max_start_nodes", "mip_max_leaves", "mip_max_improving_sols", 
"mip_lp_age_limit", "mip_pool_age_limit", "mip_pool_soft_limit", 
"mip_pscost_minreliable", "mip_min_cliquetable_entries_for_parallelism", 
"mip_report_level", "mip_feasibility_tolerance", "mip_rel_gap", 
"mip_abs_gap", "mip_heuristic_effort", "mip_heuristic_run_feasibility_jump", 
"mip_heuristic_run_rins", "mip_heuristic_run_rens", "mip_heuristic_run_root_reduced_cost", 
"mip_heuristic_run_zi_round", "mip_heuristic_run_shifting", "mip_min_logging_interval", 
"mip_lp_solver", "mip_ipm_solver", "mip_improving_solution_save", 
"mip_improving_solution_report_sparse", "mip_improving_solution_file", 
"mip_root_presolve_only", "mip_lifting_for_probing"), type = c("string", 
"string", "string", "string", "double", "string", "string", "string", 
"string", "string", "integer", "string", "double", "double", 
"double", "double", "double", "double", "double", "double", "double", 
"double", "double", "double", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "string", 
"bool", "bool", "bool", "integer", "integer", "string", "string", 
"bool", "bool", "bool", "double", "integer", "string", "string", 
"integer", "bool", "bool", "integer", "integer", "double", "integer", 
"integer", "double", "integer", "bool", "integer", "bool", "bool", 
"bool", "bool", "bool", "bool", "bool", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "bool", "bool", "bool", "bool", "double", "double", 
"double", "double", "double", "double", "double", "double", "double", 
"double", "double", "bool", "bool", "bool", "bool", "integer", 
"double", "bool", "bool", "string", "double", "integer", "integer", 
"bool", "bool", "bool", "bool", "integer", "integer", "integer", 
"integer", "integer", "integer", "integer", "integer", "integer", 
"integer", "integer", "double", "double", "double", "double", 
"bool", "bool", "bool", "bool", "bool", "bool", "double", "string", 
"string", "bool", "bool", "string", "bool", "integer")), class = "data.frame", row.names = c(NA, 
-147L))
